@@ -165,9 +165,9 @@ class ANN():
             
             for i in range(len(structure)):
                 if i == 0:
-                    self.w_layers.append(np.random.randn(input_shape[1], structure[0]) / 2*np.sqrt(input_shape[1]*structure[0]))
+                    self.w_layers.append(np.random.randn(input_shape[1], structure[0]) *np.sqrt(2/input_shape[1]))
                 else:
-                    self.w_layers.append(np.random.randn(structure[i-1], structure[i]) / 2*np.sqrt(structure[i-1]*structure[i]))
+                    self.w_layers.append(np.random.randn(structure[i-1], structure[i]) * np.sqrt(2/structure[i-1]))
                 
             for i in range(len(structure)):
                 #self.biases.append(np.random.randn(input_shape[0], structure[i]))
